;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dired-du-duc" "20251223.1946"
  "Speed up dired-du with duc."
  '((emacs    "29.1")
    (dired-du "0.5.2"))
  :url "https://github.com/meedstrom/dired-du-duc"
  :commit "8b72d0a3c42332f23ca3c9fe7a940c9c0db2e474"
  :revdesc "8b72d0a3c423"
  :keywords '("files")
  :authors '(("Martin Edström" . "meedstrom91@gmail.com"))
  :maintainers '(("Martin Edström" . "meedstrom91@gmail.com")))
